Crate maudit_rolldown_error_fork

Structs

AmbiguousExternalNamespaceModule
BuildDiagnostic
DiagnosticOptions
UnloadableDependencyContext

Enums

CjsExportSpan
Only record start offset for efficiency and simplicity
DiagnosableArcstr
A Hybrid string type used for diagnostic, e.g. for UnresolvedError, a specifier could be either a slice from raw source, or created during ast transformation. When the specifier came from raw source, we could use the Span information to give user better DX, otherwise, we could just use the string to create a fallback message.
EventKind
InvalidOptionType
Severity

Traits

ResultExt

Functions

line_column_to_byte_offset
Creating a ByteLocator is none trivial, if you want to query offset multiple times for same source, please creating a ByteLocator and calling byte_offset

Type Aliases

BuildResult
SingleBuildResult