Structs
Enums
- CjsExport
Span - Only record start offset for efficiency and simplicity
- Diagnosable
Arcstr - A Hybrid string type used for diagnostic, e.g.
for
UnresolvedError, a specifier could be either a slice from raw source, or created during ast transformation. When the specifier came from raw source, we could use theSpaninformation to give user better DX, otherwise, we could just use the string to create a fallback message. - Event
Kind - Invalid
Option Type - Severity
Traits
Functions
- line_
column_ to_ byte_ offset - Creating a ByteLocator is none trivial, if you want to query offset multiple times for same
source, please creating a
ByteLocatorand callingbyte_offset